/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.repl.bootstrap;

import org.apache.hadoop.hive.ql.exec.Task;
import org.apache.hadoop.hive.ql.exec.util.DAGTraversal;

import java.io.Serializable;
import java.util.Collections;
import java.util.List;

public class AddDependencyToLeaves implements DAGTraversal.Function {
  private List<Task<? extends Serializable>> postDependencyCollectionTasks;

  AddDependencyToLeaves(List<Task<? extends Serializable>> postDependencyCollectionTasks) {
    this.postDependencyCollectionTasks = postDependencyCollectionTasks;
  }

  public AddDependencyToLeaves(Task<? extends Serializable> postDependencyTask) {
    this(Collections.singletonList(postDependencyTask));
  }


  @Override
  public void process(Task<? extends Serializable> task) {
    if (task.getChildTasks() == null) {
      postDependencyCollectionTasks.forEach(task::addDependentTask);
    }
  }

  @Override
  public boolean skipProcessing(Task<? extends Serializable> task) {
    return postDependencyCollectionTasks.contains(task);
  }
}
