/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.hooks;

import java.io.Closeable;
import java.io.IOException;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.io.NullWritable;
import org.apache.hadoop.io.SequenceFile;

import com.google.protobuf.MessageLite;
import com.google.protobuf.Parser;

public class ProtoMessageReader<T extends MessageLite> implements Closeable {
  private final Path filePath;
  private final SequenceFile.Reader reader;
  private final ProtoMessageWritable<T> writable;

  ProtoMessageReader(Configuration conf, Path filePath, Parser<T> parser) throws IOException {
    this.filePath = filePath;
    this.reader = new SequenceFile.Reader(conf, SequenceFile.Reader.file(filePath));
    this.writable = new ProtoMessageWritable<>(parser);
  }

  public Path getFilePath() {
    return filePath;
  }

  public void setOffset(long offset) throws IOException {
    reader.seek(offset);
  }

  public long getOffset() throws IOException {
    return reader.getPosition();
  }

  public T readEvent() throws IOException {
    if (!reader.next(NullWritable.get(), writable)) {
      return null;
    }
    return writable.getMessage();
  }

  @Override
  public void close() throws IOException {
    reader.close();
  }
}
